@@ -9,6 +9,7 @@
 #                        |  |_|  /  |  |  /  |  |  / \_
 #                         \/  |_/   |_/|_/\_/|_/|_/ \/
 
+__version__ = '0.0.3'
 import re
 
 #  ERGO  Morelia should raise a form in any state!
@@ -61,26 +62,21 @@ class Morelia:
         
     def enforce(self, condition, diagnostic):
         if not condition:
-            raise SyntaxError(self.format_diagnostic(diagnostic)) #  CONSIDER format in editor-ready syntax??
+            raise SyntaxError(self.format_fault(diagnostic)) #  CONSIDER format in editor-ready syntax??
 
-    def format_diagnostic(self, diagnostic):  #  TODO  move down to Step
+    def format_fault(self, diagnostic):
         parent_reconstruction = ''
-        if self.parent:
-            parent_reconstruction = self.parent.reconstruction().replace('\n', '\\n')
+        if self.parent:  parent_reconstruction = self.parent.reconstruction().replace('\n', '\\n')
         reconstruction = self.reconstruction().replace('\n', '\\n')
-        expect = '''
-  File "%s", line %s, in %s
-    %s
-%s''' % (self.get_filename(), self.line_number, parent_reconstruction, reconstruction, diagnostic)
-
-        return expect
+        args = (self.get_filename(), self.line_number, parent_reconstruction, reconstruction, diagnostic)
+        return '\n  File "%s", line %s, in %s\n    %s\n%s' % args
     
     def reconstruction(self):
-        return self.concept + ': ' + self.predicate  #  TODO does anyone else need this?
+        return self.concept + ': ' + self.predicate
 
     def get_filename(self):
         node = self
-        
+
         while node:
             if not node.parent and hasattr(node, 'filename'):  return node.filename
             node = node.parent
@@ -191,7 +187,7 @@ class Parser:
         if self.steps != []:
             self.steps[0].evaluate_steps(v)
 
-    def parse_feature(self, lines):    #  TODO  preserve and use line numbers
+    def parse_feature(self, lines):
         self.line_number = 0
         
         for self.line in lines.split('\n'):      #  TODO  deal with pesky \r
@@ -220,8 +216,7 @@ class Parser:
         for klass in self.thangs:
             self.thang = klass()
             name = self.thang.i_look_like()
-            rx = '\s*(' + name + '):?\s*(.*)'  #  TODO  Givenfoo is wrong
-            
+            rx = '\s*(' + name + '):?\s*(.*)'
             m = re.compile(rx).match(self.line)
 
             if m and len(m.groups()) > 0:
@@ -246,14 +241,14 @@ class ReportVisitor:
     def __init__(self, suite):  self.suite = suite
 
     def visit(self, node):
-        print node.prefix() + node.concept + ': ' + node.predicate # TODO  if verbose
+        print node.prefix() + node.reconstruction()
 
 
 class TestVisitor:
     def __init__(self, suite):  self.suite = suite
 
     def visit(self, node):
-        # print node.concept + ': ' + node.predicate # TODO  if verbose
+        # print node.reconstruction()  # TODO  if verbose
         self.suite.step = node
         node.evaluate_step(self)
 
@@ -315,7 +310,7 @@ class Step(Viridis):
             self.method(*self.matches)
         except (AssertionError, SyntaxError), e:
             args = list(e.args)
-            args[0] = self.format_diagnostic(e.args[0])
+            args[0] = self.format_fault(e.args[0])  # TODO  have we seen this before?
             e.args = tuple(e.args)
             raise e.__class__(*args)
 
@@ -397,7 +392,7 @@ if __name__ == '__main__':
 #  TODO  maximum munch fails - Given must start a line
 
 
-def _special_range(n):  #  TODO  better name
+def _special_range(n):  #  CONSIDER  better name
     return xrange(n) if n else [0]
 
 
@@ -424,3 +419,5 @@ def _imap(function, *iterables):
             yield tuple(args)
         else:
             yield function(*args)
+
+#  CONSIDER  display all missing steps not just the first
